diff --git a/BUILD_WIN.md b/BUILD_WIN.md
index bdab7e6e6d..f74895b8a3 100644
--- a/BUILD_WIN.md
+++ b/BUILD_WIN.md
@@ -47,7 +47,7 @@ Download and install the latest version of CMake 3.15.
Download the file named win64-x64 Installer from the [CMake Website](https://cmake.org/download/). You can access the installer on this [3.15 Version page](https://cmake.org/files/v3.15/). During installation, make sure to check "Add CMake to system PATH for all users" when prompted.
### Step 4. Create VCPKG environment variable
-In the next step, you will use CMake to build Project Athena. By default, the CMake process builds dependency files in Windows' `%TEMP%` directory, which is periodically cleared by the operating system. To prevent you from having to re-build the dependencies in the event that Windows clears that directory, we recommend that you create a `HIFI_VCPKG_BASE` environment variable linked to a directory somewhere on your machine. That directory will contain all dependency files until you manually remove them.
+In the next step, you will use CMake to build Vircadia. By default, the CMake process builds dependency files in Windows' `%TEMP%` directory, which is periodically cleared by the operating system. To prevent you from having to re-build the dependencies in the event that Windows clears that directory, we recommend that you create a `HIFI_VCPKG_BASE` environment variable linked to a directory somewhere on your machine. That directory will contain all dependency files until you manually remove them.
To create this variable:
* Naviagte to 'Edit the System Environment Variables' Through the start menu.
@@ -98,7 +98,7 @@ Restart Visual Studio again.
In Visual Studio, right+click "interface" under the Apps folder in Solution Explorer and select "Set as Startup Project". Run from the menu bar `Debug > Start Debugging`.
-Now, you should have a full build of Project Athena and be able to run the Interface using Visual Studio. Please check our [Docs](https://wiki.highfidelity.com/wiki/Main_Page) for more information regarding the programming workflow.
+Now, you should have a full build of Vircadia and be able to run the Interface using Visual Studio. Please check our [Docs](https://docs.vircadia.dev/) for more information regarding the programming workflow.
Note: You can also run Interface by launching it from command line or File Explorer from `%HIFI_DIR%\build\interface\Release\interface.exe`
diff --git a/CODING_STANDARD.md b/CODING_STANDARD.md
index fd1843e981..e582ac305f 100644
--- a/CODING_STANDARD.md
+++ b/CODING_STANDARD.md
@@ -976,9 +976,9 @@ while (true) {
#### [4.3.4] Source files (header and implementation) must include a boilerplate.
-Boilerplates should include the filename, location, creator, copyright Project Athena contributors, and Apache 2.0 License
+Boilerplates should include the filename, location, creator, copyright Vircadia contributors, and Apache 2.0 License
information. This should be placed at the top of the file. If editing an existing file that is copyright High Fidelity, add a
-second copyright line, copyright Project Athena contributors.
+second copyright line, copyright Vircadia contributors.
```cpp
//
@@ -987,7 +987,7 @@ second copyright line, copyright Project Athena contributors.
//
// Created by Stephen Birarda on 15 Feb 2013.
// Copyright 2013 High Fidelity, Inc.
-// Copyright 2020 Project Athena contributors.
+// Copyright 2020 Vircadia contributors.
//
// This is where you could place an optional one line comment about the file.
//
diff --git a/INSTALL.md b/INSTALL.md
index 10858200e7..c0418a7521 100644
--- a/INSTALL.md
+++ b/INSTALL.md
@@ -1,10 +1,10 @@
# Creating an Installer
-Follow the [build guide](BUILD.md) to figure out how to build Project Athena for your platform.
+Follow the [build guide](BUILD.md) to figure out how to build Vircadia for your platform.
During generation, CMake should produce an `install` target and a `package` target.
-The `install` target will copy the Project Athena targets and their dependencies to your `CMAKE_INSTALL_PREFIX`.
+The `install` target will copy the Vircadia targets and their dependencies to your `CMAKE_INSTALL_PREFIX`.
This variable is set by the `project(hifi)` command in `CMakeLists.txt` to `C:/Program Files/hifi` and stored in `build/CMakeCache.txt`
### Packaging
diff --git a/LICENSE b/LICENSE
index f88e751de5..51e1023f21 100644
--- a/LICENSE
+++ b/LICENSE
@@ -1,7 +1,7 @@
Copyright (c) 2013-2019, High Fidelity, Inc.
-Copyright (c) 2019-2020, Project Athena Contributors.
+Copyright (c) 2019-2020, Vircadia Contributors.
All rights reserved.
-https://projectathena.io
+https://vircadia.com/
Licensed under the Apache License version 2.0 (the "License");
You may not use this software except in compliance with the License.
diff --git a/cmake/installer/installer-header.bmp b/cmake/installer/installer-header.bmp
index 2d262d3ef9..52fd28a933 100644
Binary files a/cmake/installer/installer-header.bmp and b/cmake/installer/installer-header.bmp differ
diff --git a/cmake/installer/installer.ico b/cmake/installer/installer.ico
index 63a3eff482..b337544f88 100644
Binary files a/cmake/installer/installer.ico and b/cmake/installer/installer.ico differ
diff --git a/cmake/installer/uninstaller-header.bmp b/cmake/installer/uninstaller-header.bmp
index 2d262d3ef9..52fd28a933 100644
Binary files a/cmake/installer/uninstaller-header.bmp and b/cmake/installer/uninstaller-header.bmp differ
diff --git a/cmake/macros/GenerateInstallers.cmake b/cmake/macros/GenerateInstallers.cmake
index 83bdefeada..0442df55cf 100644
--- a/cmake/macros/GenerateInstallers.cmake
+++ b/cmake/macros/GenerateInstallers.cmake
@@ -18,20 +18,20 @@ macro(GENERATE_INSTALLERS)
if (CLIENT_ONLY)
set(_PACKAGE_NAME_EXTRA "-Interface")
set(INSTALLER_TYPE "client_only")
- string(REGEX REPLACE "Project Athena" "Project Athena Interface" _DISPLAY_NAME ${BUILD_ORGANIZATION})
+ string(REGEX REPLACE "Vircadia" "Vircadia Interface" _DISPLAY_NAME ${BUILD_ORGANIZATION})
elseif (SERVER_ONLY)
set(_PACKAGE_NAME_EXTRA "-Sandbox")
set(INSTALLER_TYPE "server_only")
- string(REGEX REPLACE "Project Athena" "Project Athena Sandbox" _DISPLAY_NAME ${BUILD_ORGANIZATION})
+ string(REGEX REPLACE "Vircadia" "Vircadia Sandbox" _DISPLAY_NAME ${BUILD_ORGANIZATION})
else ()
set(_DISPLAY_NAME ${BUILD_ORGANIZATION})
set(INSTALLER_TYPE "full")
endif ()
set(CPACK_PACKAGE_NAME ${_DISPLAY_NAME})
- set(CPACK_PACKAGE_VENDOR "Project Athena")
+ set(CPACK_PACKAGE_VENDOR "Vircadia")
set(CPACK_PACKAGE_VERSION ${BUILD_VERSION})
- set(CPACK_PACKAGE_FILE_NAME "ProjectAthena-Alpha${_PACKAGE_NAME_EXTRA}-${BUILD_VERSION}")
+ set(CPACK_PACKAGE_FILE_NAME "Vircadia-Alpha${_PACKAGE_NAME_EXTRA}-${BUILD_VERSION}")
set(CPACK_NSIS_DISPLAY_NAME ${_DISPLAY_NAME})
set(CPACK_NSIS_PACKAGE_NAME ${_DISPLAY_NAME})
if (PR_BUILD)
@@ -118,11 +118,11 @@ macro(GENERATE_INSTALLERS)
set(CPACK_RESOURCE_FILE_LICENSE "${CMAKE_SOURCE_DIR}/LICENSE")
if (BUILD_CLIENT)
- cpack_add_component(${CLIENT_COMPONENT} DISPLAY_NAME "Project Athena Interface")
+ cpack_add_component(${CLIENT_COMPONENT} DISPLAY_NAME "Vircadia Interface")
endif ()
if (BUILD_SERVER)
- cpack_add_component(${SERVER_COMPONENT} DISPLAY_NAME "Project Athena Sandbox")
+ cpack_add_component(${SERVER_COMPONENT} DISPLAY_NAME "Vircadia Sandbox")
endif ()
include(CPack)
diff --git a/cmake/macros/SetPackagingParameters.cmake b/cmake/macros/SetPackagingParameters.cmake
index 935996850b..1b7b3dbe8e 100644
--- a/cmake/macros/SetPackagingParameters.cmake
+++ b/cmake/macros/SetPackagingParameters.cmake
@@ -35,7 +35,7 @@ macro(SET_PACKAGING_PARAMETERS)
set(DEPLOY_PACKAGE TRUE)
set(PRODUCTION_BUILD 1)
set(BUILD_VERSION ${RELEASE_NUMBER})
- set(BUILD_ORGANIZATION "Project Athena")
+ set(BUILD_ORGANIZATION "Vircadia")
set(HIGH_FIDELITY_PROTOCOL "hifi")
set(HIGH_FIDELITY_APP_PROTOCOL "hifiapp")
set(INTERFACE_BUNDLE_NAME "interface")
@@ -60,7 +60,7 @@ macro(SET_PACKAGING_PARAMETERS)
set(DEPLOY_PACKAGE TRUE)
set(PR_BUILD 1)
set(BUILD_VERSION "PR${RELEASE_NUMBER}")
- set(BUILD_ORGANIZATION "Project Athena - PR${RELEASE_NUMBER}")
+ set(BUILD_ORGANIZATION "Vircadia - PR${RELEASE_NUMBER}")
set(INTERFACE_BUNDLE_NAME "interface")
set(INTERFACE_ICON_PREFIX "interface-beta")
@@ -69,7 +69,7 @@ macro(SET_PACKAGING_PARAMETERS)
else ()
set(DEV_BUILD 1)
set(BUILD_VERSION "dev")
- set(BUILD_ORGANIZATION "Project Athena - ${BUILD_VERSION}")
+ set(BUILD_ORGANIZATION "Vircadia - ${BUILD_VERSION}")
set(INTERFACE_BUNDLE_NAME "interface")
set(INTERFACE_ICON_PREFIX "interface-beta")
@@ -171,21 +171,21 @@ macro(SET_PACKAGING_PARAMETERS)
# shortcut names
if (PRODUCTION_BUILD)
- set(INTERFACE_SHORTCUT_NAME "Project Athena")
+ set(INTERFACE_SHORTCUT_NAME "Vircadia")
set(CONSOLE_SHORTCUT_NAME "Console")
set(SANDBOX_SHORTCUT_NAME "Sandbox")
set(APP_USER_MODEL_ID "com.highfidelity.console")
else ()
- set(INTERFACE_SHORTCUT_NAME "Project Athena - ${BUILD_VERSION_NO_SHA}")
+ set(INTERFACE_SHORTCUT_NAME "Vircadia - ${BUILD_VERSION_NO_SHA}")
set(CONSOLE_SHORTCUT_NAME "Console - ${BUILD_VERSION_NO_SHA}")
set(SANDBOX_SHORTCUT_NAME "Sandbox - ${BUILD_VERSION_NO_SHA}")
endif ()
set(INTERFACE_HF_SHORTCUT_NAME "${INTERFACE_SHORTCUT_NAME}")
- set(CONSOLE_HF_SHORTCUT_NAME "Project Athena ${CONSOLE_SHORTCUT_NAME}")
- set(SANDBOX_HF_SHORTCUT_NAME "Project Athena ${SANDBOX_SHORTCUT_NAME}")
+ set(CONSOLE_HF_SHORTCUT_NAME "Vircadia ${CONSOLE_SHORTCUT_NAME}")
+ set(SANDBOX_HF_SHORTCUT_NAME "Vircadia ${SANDBOX_SHORTCUT_NAME}")
- set(PRE_SANDBOX_INTERFACE_SHORTCUT_NAME "Project Athena")
+ set(PRE_SANDBOX_INTERFACE_SHORTCUT_NAME "Vircadia")
set(PRE_SANDBOX_CONSOLE_SHORTCUT_NAME "Server Console")
# check if we need to find signtool
diff --git a/cmake/templates/NSIS.template.in b/cmake/templates/NSIS.template.in
index 0e4c2f3579..8e621b8f2d 100644
--- a/cmake/templates/NSIS.template.in
+++ b/cmake/templates/NSIS.template.in
@@ -720,7 +720,7 @@ Function InstallTypesPage
StrCpy $OffsetUnits u
StrCpy $Express "0"
- ${NSD_CreateRadioButton} 30% $CurrentOffset$OffsetUnits 100% 10u "Express Install (Recommended)"; $\nInstalls Project Athena Interface and Project Athena Sandbox"
+ ${NSD_CreateRadioButton} 30% $CurrentOffset$OffsetUnits 100% 10u "Express Install (Recommended)"; $\nInstalls Vircadia Interface and Vircadia Sandbox"
pop $ExpressInstallRadioButton
${NSD_OnClick} $ExpressInstallRadioButton ChangeExpressLabel
IntOp $CurrentOffset $CurrentOffset + 15
@@ -973,7 +973,7 @@ Function ReadPostInstallOptions
${If} @CLIENT_COMPONENT_CONDITIONAL@
${LogText} "Option: Install Client"
- ; check if the user asked for a desktop shortcut to Project Athena
+ ; check if the user asked for a desktop shortcut to Vircadia
${NSD_GetState} $DesktopClientCheckbox $DesktopClientState
${LogText} "Option: Create Client Desktop Shortcut: $DesktopClientState"
${EndIf}
@@ -1027,7 +1027,7 @@ Function HandlePostInstallOptions
${EndIf}
${If} @CLIENT_COMPONENT_CONDITIONAL@
- ; check if the user asked for a desktop shortcut to Project Athena
+ ; check if the user asked for a desktop shortcut to Vircadia
${If} $DesktopClientState == ${BST_CHECKED}
CreateShortCut "$DESKTOP\@INTERFACE_HF_SHORTCUT_NAME@.lnk" "$INSTDIR\@INTERFACE_WIN_EXEC_NAME@"
!insertmacro WriteInstallOption "@CLIENT_DESKTOP_SHORTCUT_REG_KEY@" YES
@@ -1088,7 +1088,7 @@ Function HandlePostInstallOptions
ClearErrors
; copy the data from production build to this PR build
- CopyFiles "$APPDATA\Project Athena\*" $0
+ CopyFiles "$APPDATA\Vircadia\*" $0
; handle an error in copying files
IfErrors 0 NoError
diff --git a/interface/CMakeLists.txt b/interface/CMakeLists.txt
index dc9e5254df..1a0e279674 100644
--- a/interface/CMakeLists.txt
+++ b/interface/CMakeLists.txt
@@ -159,7 +159,7 @@ elseif (WIN32)
set(CONFIGURE_ICON_RC_OUTPUT "${CMAKE_CURRENT_BINARY_DIR}/Icon.rc")
configure_file("${HF_CMAKE_DIR}/templates/Icon.rc.in" ${CONFIGURE_ICON_RC_OUTPUT})
- set(APP_FULL_NAME "Project Athena")
+ set(APP_FULL_NAME "Vircadia")
set(CONFIGURE_VERSION_INFO_RC_OUTPUT "${CMAKE_CURRENT_BINARY_DIR}/VersionInfo.rc")
configure_file("${HF_CMAKE_DIR}/templates/VersionInfo.rc.in" ${CONFIGURE_VERSION_INFO_RC_OUTPUT})
diff --git a/interface/resources/images/Loading-Inner-H.png b/interface/resources/images/Loading-Inner-H.png
index 93369d61c8..06359f0c35 100644
Binary files a/interface/resources/images/Loading-Inner-H.png and b/interface/resources/images/Loading-Inner-H.png differ
diff --git a/interface/resources/images/about-projectathena.png b/interface/resources/images/about-projectathena.png
deleted file mode 100644
index ae2d2bcd06..0000000000
Binary files a/interface/resources/images/about-projectathena.png and /dev/null differ
diff --git a/interface/resources/images/about-vircadia.png b/interface/resources/images/about-vircadia.png
new file mode 100644
index 0000000000..38ece8a154
Binary files /dev/null and b/interface/resources/images/about-vircadia.png differ
diff --git a/interface/resources/images/hifi-logo-blackish.svg b/interface/resources/images/hifi-logo-blackish.svg
deleted file mode 100644
index 60bfb3d418..0000000000
--- a/interface/resources/images/hifi-logo-blackish.svg
+++ /dev/null
@@ -1,123 +0,0 @@
-
-
-
-
\ No newline at end of file
diff --git a/interface/resources/images/hifi-logo.svg b/interface/resources/images/hifi-logo.svg
deleted file mode 100644
index e5d66d8f18..0000000000
--- a/interface/resources/images/hifi-logo.svg
+++ /dev/null
@@ -1,58 +0,0 @@
-
-
-
-
diff --git a/interface/resources/images/project-athena-banner-color2.svg b/interface/resources/images/project-athena-banner-color2.svg
deleted file mode 100644
index b41a980fe0..0000000000
--- a/interface/resources/images/project-athena-banner-color2.svg
+++ /dev/null
@@ -1,157 +0,0 @@
-
-
diff --git a/interface/resources/images/vircadia-banner.svg b/interface/resources/images/vircadia-banner.svg
new file mode 100644
index 0000000000..d954a96192
--- /dev/null
+++ b/interface/resources/images/vircadia-banner.svg
@@ -0,0 +1,95 @@
+
+
\ No newline at end of file
diff --git a/interface/resources/images/vircadia-logo.svg b/interface/resources/images/vircadia-logo.svg
new file mode 100644
index 0000000000..10645c4120
--- /dev/null
+++ b/interface/resources/images/vircadia-logo.svg
@@ -0,0 +1,60 @@
+
+
\ No newline at end of file
diff --git a/interface/resources/qml/LoginDialog.qml b/interface/resources/qml/LoginDialog.qml
index fbc8f9495a..ec98498db6 100644
--- a/interface/resources/qml/LoginDialog.qml
+++ b/interface/resources/qml/LoginDialog.qml
@@ -85,7 +85,7 @@ FocusScope {
Image {
id: banner
anchors.centerIn: parent
- source: "../images/project-athena-banner-color2.svg"
+ source: "../images/vircadia-banner.svg"
horizontalAlignment: Image.AlignHCenter
}
}
diff --git a/interface/resources/qml/LoginDialog/SignUpBody.qml b/interface/resources/qml/LoginDialog/SignUpBody.qml
index 7347464f4e..fcb47c3534 100644
--- a/interface/resources/qml/LoginDialog/SignUpBody.qml
+++ b/interface/resources/qml/LoginDialog/SignUpBody.qml
@@ -23,7 +23,7 @@ Item {
clip: true
height: root.height
width: root.width
- readonly property string termsContainerText: qsTr("By signing up, you agree to Project Athena's Terms of Service")
+ readonly property string termsContainerText: qsTr("By signing up, you agree to Vircadia's Terms of Service")
property int textFieldHeight: 31
property string fontFamily: "Raleway"
property int fontSize: 15
@@ -395,7 +395,7 @@ Item {
text: signUpBody.termsContainerText
Component.onCompleted: {
// with the link.
- termsText.text = qsTr("By signing up, you agree to Project Athena's Terms of Service")
+ termsText.text = qsTr("By signing up, you agree to Vircadia's Terms of Service")
}
}
diff --git a/interface/resources/qml/LoginDialog/UsernameCollisionBody.qml b/interface/resources/qml/LoginDialog/UsernameCollisionBody.qml
index 8b3c878d46..9710723bed 100644
--- a/interface/resources/qml/LoginDialog/UsernameCollisionBody.qml
+++ b/interface/resources/qml/LoginDialog/UsernameCollisionBody.qml
@@ -19,7 +19,7 @@ import TabletScriptingInterface 1.0
Item {
id: usernameCollisionBody
clip: true
- readonly property string termsContainerText: qsTr("By creating this user profile, you agree to Project Athena's Terms of Service")
+ readonly property string termsContainerText: qsTr("By creating this user profile, you agree to Vircadia's Terms of Service")
width: root.width
height: root.height
readonly property string fontFamily: "Raleway"
@@ -218,7 +218,7 @@ Item {
text: usernameCollisionBody.termsContainerText
Component.onCompleted: {
// with the link.
- termsText.text = qsTr("By creating this user profile, you agree to Project Athena's Terms of Service")
+ termsText.text = qsTr("By creating this user profile, you agree to Vircadia's Terms of Service")
}
}
diff --git a/interface/resources/qml/UpdateDialog.qml b/interface/resources/qml/UpdateDialog.qml
index 9c22d0b65b..c3a7a45c69 100644
--- a/interface/resources/qml/UpdateDialog.qml
+++ b/interface/resources/qml/UpdateDialog.qml
@@ -47,7 +47,7 @@ ScrollingWindow {
Image {
id: logo
- source: "../images/hifi-logo.svg"
+ source: "../images/vircadia-logo.svg"
width: updateDialog.logoSize
height: updateDialog.logoSize
anchors {
diff --git a/interface/resources/qml/dialogs/TabletLoginDialog.qml b/interface/resources/qml/dialogs/TabletLoginDialog.qml
index a7e5c236ca..12198caf08 100644
--- a/interface/resources/qml/dialogs/TabletLoginDialog.qml
+++ b/interface/resources/qml/dialogs/TabletLoginDialog.qml
@@ -129,7 +129,7 @@ FocusScope {
Image {
id: banner
anchors.centerIn: parent
- source: "../../images/project-athena-banner-color2.svg"
+ source: "../../images/vircadia-banner.svg"
horizontalAlignment: Image.AlignHCenter
}
}
diff --git a/interface/resources/qml/hifi/avatarPackager/AvatarPackagerHeader.qml b/interface/resources/qml/hifi/avatarPackager/AvatarPackagerHeader.qml
index edb862b023..128ef61c75 100644
--- a/interface/resources/qml/hifi/avatarPackager/AvatarPackagerHeader.qml
+++ b/interface/resources/qml/hifi/avatarPackager/AvatarPackagerHeader.qml
@@ -128,7 +128,7 @@ ShadowRectangle {
}
}
- // FIXME: Link to a Project Athena version of the video.
+ // FIXME: Link to a Vircadias version of the video.
/*
RalewayButton {
id: video
diff --git a/interface/resources/qml/hifi/dialogs/TabletAboutDialog.qml b/interface/resources/qml/hifi/dialogs/TabletAboutDialog.qml
index 2be66442ce..c761312152 100644
--- a/interface/resources/qml/hifi/dialogs/TabletAboutDialog.qml
+++ b/interface/resources/qml/hifi/dialogs/TabletAboutDialog.qml
@@ -25,7 +25,7 @@ Rectangle {
Image {
sourceSize.width: 295
sourceSize.height: 75
- source: "../../../images/about-projectathena.png"
+ source: "../../../images/about-vircadia.png"
}
Item { height: 30; width: 1 }
Column {
@@ -53,7 +53,7 @@ Rectangle {
textFormat: Text.StyledText
linkColor: "#00B4EF"
color: "white"
- text: "Project Athena Github."
+ text: "Vircadia Github."
size: 20
onLinkActivated: {
HiFiAbout.openUrl("https:/github.com/kasenvr/project-athena");
@@ -116,7 +116,7 @@ Rectangle {
Item { height: 20; width: 1 }
RalewayRegular {
color: "white"
- text: "© 2019 - 2020 Project Athena Contributors."
+ text: "© 2019 - 2020 Vircadia Contributors."
size: 14
}
RalewayRegular {
diff --git a/interface/src/Application.cpp b/interface/src/Application.cpp
index 1b22dbd329..5b681faf5e 100644
--- a/interface/src/Application.cpp
+++ b/interface/src/Application.cpp
@@ -1139,7 +1139,7 @@ Application::Application(int& argc, char** argv, QElapsedTimer& startupTimer, bo
QFontDatabase::addApplicationFont(PathUtils::resourcesPath() + "fonts/Graphik-SemiBold.ttf");
QFontDatabase::addApplicationFont(PathUtils::resourcesPath() + "fonts/Graphik-Regular.ttf");
QFontDatabase::addApplicationFont(PathUtils::resourcesPath() + "fonts/Graphik-Medium.ttf");
- _window->setWindowTitle("Project Athena");
+ _window->setWindowTitle("Vircadia");
Model::setAbstractViewStateInterface(this); // The model class will sometimes need to know view state details from us
@@ -3166,7 +3166,7 @@ void Application::showLoginScreen() {
QJsonObject loginData = {};
loginData["action"] = "login dialog popped up";
UserActivityLogger::getInstance().logAction("encourageLoginDialog", loginData);
- _window->setWindowTitle("Project Athena");
+ _window->setWindowTitle("Vircadia");
} else {
resumeAfterLoginDialogActionTaken();
}
@@ -7063,7 +7063,7 @@ void Application::updateWindowTitle() const {
auto accountManager = DependencyManager::get();
auto isInErrorState = nodeList->getDomainHandler().isInErrorState();
- QString buildVersion = " - Project Athena v0.86.0 K2 - "
+ QString buildVersion = " - Vircadia v0.86.0 K2 - "
+ (BuildInfo::BUILD_TYPE == BuildInfo::BuildType::Stable ? QString("Version") : QString("Build"))
+ " " + applicationVersion();
diff --git a/interface/src/avatar/AvatarProject.h b/interface/src/avatar/AvatarProject.h
index 4c1e55fa1c..3e0d69f78b 100644
--- a/interface/src/avatar/AvatarProject.h
+++ b/interface/src/avatar/AvatarProject.h
@@ -95,7 +95,7 @@ public:
static bool isValidNewProjectName(const QString& projectPath, const QString& projectName);
static QString getDefaultProjectsPath() {
- return QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation) + "/Project Athena Projects";
+ return QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation) + "/Vircadia Projects";
}
signals:
diff --git a/interface/src/main.cpp b/interface/src/main.cpp
index 81616e5773..46720fea3e 100644
--- a/interface/src/main.cpp
+++ b/interface/src/main.cpp
@@ -379,7 +379,7 @@ int main(int argc, const char* argv[]) {
PROFILE_SYNC_END(startup, "app full ctor", "");
#if defined(Q_OS_LINUX)
- app.setWindowIcon(QIcon(PathUtils::resourcesPath() + "images/hifi-logo.svg"));
+ app.setWindowIcon(QIcon(PathUtils::resourcesPath() + "images/vircadia-logo.svg"));
#endif
QTimer exitTimer;
diff --git a/libraries/networking/src/MetaverseAPI.cpp b/libraries/networking/src/MetaverseAPI.cpp
index 0fb0bcecad..73316ecda3 100644
--- a/libraries/networking/src/MetaverseAPI.cpp
+++ b/libraries/networking/src/MetaverseAPI.cpp
@@ -3,7 +3,7 @@
// libraries/networking/src
//
// Created by Kalila (kasenvr) on 2019-12-16.
-// Copyright 2019 Project Athena
+// Copyright 2019 Vircadia
//
// Distributed under the Apache License, Version 2.0.
// See the accompanying file LICENSE or http://www.apache.org/licenses/LICENSE-2.0.html
diff --git a/libraries/networking/src/MetaverseAPI.h b/libraries/networking/src/MetaverseAPI.h
index 423f465229..026f8d8b70 100644
--- a/libraries/networking/src/MetaverseAPI.h
+++ b/libraries/networking/src/MetaverseAPI.h
@@ -3,7 +3,7 @@
// libraries/networking/src
//
// Created by Kalila (kasenvr) on 2019-12-16.
-// Copyright 2019 Project Athena
+// Copyright 2019 Vircadia
//
// Distributed under the Apache License, Version 2.0.
// See the accompanying file LICENSE or http://www.apache.org/licenses/LICENSE-2.0.html
diff --git a/pkg-scripts/athena-server.spec b/pkg-scripts/athena-server.spec
index 7910c8114b..6c751a8e50 100644
--- a/pkg-scripts/athena-server.spec
+++ b/pkg-scripts/athena-server.spec
@@ -5,11 +5,11 @@
Name: athena-server
Version: %{version}
Release: 1%{?dist}
-Summary: Project Athena metaverse platform, based on the High Fidelity Engine.
+Summary: Vircadia metaverse platform, based on the High Fidelity Engine.
License: ASL 2.0
-URL: https://projectathena.io
-Source0: https://github.com/daleglass/athena-builder/blob/master/athena_builder
+URL: https://vircadia.com
+Source0: https://github.com/daleglass/vircadia-builder/blob/master/vircadia-builder
#BuildRequires: systemd-rpm-macros
BuildRequires: chrpath
@@ -19,8 +19,8 @@ AutoReq: no
AutoProv: no
%description
-Project Athena allows creation and sharing of VR experiences.
- The Project Athena metaverse provides built-in social features, including avatar interactions, spatialized audio and interactive physics. Additionally, you have the ability to import any 3D object into your virtual environment.
+Vircadia allows creation and sharing of VR experiences.
+ The Vircadia metaverse provides built-in social features, including avatar interactions, spatialized audio and interactive physics. Additionally, you have the ability to import any 3D object into your virtual environment.
%prep
diff --git a/pkg-scripts/server-control b/pkg-scripts/server-control
index 70383891bd..708b8ce398 100644
--- a/pkg-scripts/server-control
+++ b/pkg-scripts/server-control
@@ -4,12 +4,12 @@ Priority: optional
Maintainer: Heather Anderson
Build-Depends: debhelper (>= 10)
Standards-Version: 4.1.2
-Homepage: https://www.projectathena.dev
+Homepage: https://vircadia.com
Vcs-Git: https://github.com/kasenvr/project-athena.git
Vcs-Browser: https://github.com/kasenvr/project-athena
Package: athena-server
Architecture: any
Depends: adduser, {DEPENDS}
-Description: Project Athena allows creation and sharing of VR experiences.
- The Project Athena metaverse provides built-in social features, including avatar interactions, spatialized audio and interactive physics. Additionally, you have the ability to import any 3D object into your virtual environment.
+Description: Vircadia allows creation and sharing of VR experiences.
+ The Vircadia metaverse provides built-in social features, including avatar interactions, spatialized audio and interactive physics. Additionally, you have the ability to import any 3D object into your virtual environment.
diff --git a/scripts/system/create/entityProperties/html/entityProperties.html b/scripts/system/create/entityProperties/html/entityProperties.html
index 6eadf4d3c0..eef1c33829 100644
--- a/scripts/system/create/entityProperties/html/entityProperties.html
+++ b/scripts/system/create/entityProperties/html/entityProperties.html
@@ -4,7 +4,7 @@
//
// Created by Ryan Huffman on 13 Nov 2014
// Copyright 2014 High Fidelity, Inc.
-// Copyright 2020 Project Athena contributors.
+// Copyright 2020 Vircadia contributors.
//
// Distributed under the Apache License, Version 2.0.
// See the accompanying file LICENSE or http://www.apache.org/licenses/LICENSE-2.0.html
diff --git a/scripts/system/html/css/tabs.css b/scripts/system/html/css/tabs.css
index b2d63b5652..6abd910300 100644
--- a/scripts/system/html/css/tabs.css
+++ b/scripts/system/html/css/tabs.css
@@ -2,7 +2,7 @@
// tabs.css
//
// Created by Alezia Kurdis on 27 Feb 2020
-// Copyright 2020 Project Athena contributors.
+// Copyright 2020 Vircadia contributors.
//
// Distributed under the Apache License, Version 2.0.
// See the accompanying file LICENSE or http://www.apache.org/licenses/LICENSE-2.0.html
diff --git a/scripts/system/more/app-more.js b/scripts/system/more/app-more.js
index 1902ddf855..97f3377b9d 100644
--- a/scripts/system/more/app-more.js
+++ b/scripts/system/more/app-more.js
@@ -4,9 +4,9 @@
// VERSION 1.0
//
// Created by Keb Helion, February 2020.
-// Copyright 2020 Project Athena and contributors.
+// Copyright 2020 Vircadia and contributors.
//
-// This script adds a "More Apps" selector to "Project Athena" to allow the user to add optional functionalities to the tablet.
+// This script adds a "More Apps" selector to "Vircadia" to allow the user to add optional functionalities to the tablet.
// This application has been designed to work directly from the Github repository.
//
// Distributed under the Apache License, Version 2.0.
diff --git a/scripts/system/more/css/styles.css b/scripts/system/more/css/styles.css
index 1f9aba0695..49412d3ccb 100644
--- a/scripts/system/more/css/styles.css
+++ b/scripts/system/more/css/styles.css
@@ -2,7 +2,7 @@
styles.css
Created by Kalila L. on 23 Feb 2020.
- Copyright 2020 Project Athena and contributors.
+ Copyright 2020 Vircadia and contributors.
Distributed under the Apache License, Version 2.0.
See the accompanying file LICENSE or http://www.apache.org/licenses/LICENSE-2.0.html
diff --git a/scripts/system/more/more.html b/scripts/system/more/more.html
index 218744969e..8cc5352b08 100644
--- a/scripts/system/more/more.html
+++ b/scripts/system/more/more.html
@@ -3,7 +3,7 @@
// more.html
//
// Created by Keb Helion, February 2020.
-// Copyright 2020 Project Athena and contributors.
+// Copyright 2020 Vircadia and contributors.
//
// App maintained in: https://github.com/kasenvr/community-apps
// App copied to: https://github.com/kasenvr/project-athena
diff --git a/scripts/system/tablet-goto.js b/scripts/system/tablet-goto.js
index 8c048cc0cc..08c1f14e6d 100644
--- a/scripts/system/tablet-goto.js
+++ b/scripts/system/tablet-goto.js
@@ -9,7 +9,7 @@
//
// Created by Dante Ruiz on 8 February 2017
// Copyright 2016 High Fidelity, Inc.
-// Copyright 2020 Project Athena contributors.
+// Copyright 2020 Vircadia contributors.
//
// Distributed under the Apache License, Version 2.0.
// See the accompanying file LICENSE or http://www.apache.org/licenses/LICENSE-2.0.html
diff --git a/interface/src/Menu.cpp b/interface/src/Menu.cpp
index b5cacd662b..ceca9debb0 100644
--- a/interface/src/Menu.cpp
+++ b/interface/src/Menu.cpp
@@ -782,21 +782,21 @@ Menu::Menu() {
// Help/Application menu ----------------------------------
MenuWrapper * helpMenu = addMenu("Help");
- // Help > About Project Athena
- action = addActionToQMenuAndActionHash(helpMenu, "About Project Athena");
+ // Help > About Vircadia
+ action = addActionToQMenuAndActionHash(helpMenu, "About Vircadia");
connect(action, &QAction::triggered, [] {
qApp->showDialog(QString("hifi/dialogs/AboutDialog.qml"),
QString("hifi/dialogs/TabletAboutDialog.qml"), "AboutDialog");
});
helpMenu->addSeparator();
// Help > Athena Docs
action = addActionToQMenuAndActionHash(helpMenu, "Online Documentation");
connect(action, &QAction::triggered, qApp, [] {
- QDesktopServices::openUrl(QUrl("https://docs.projectathena.dev/"));
+ QDesktopServices::openUrl(QUrl("https://docs.vircadia.dev/"));
});
// Help > Athena Forum
/* action = addActionToQMenuAndActionHash(helpMenu, "Online Forums");
connect(action, &QAction::triggered, qApp, [] {
QDesktopServices::openUrl(QUrl("https://forums.highfidelity.com/"));
@@ -805,7 +805,7 @@ Menu::Menu() {
// Help > Scripting Reference
action = addActionToQMenuAndActionHash(helpMenu, "Online Script Reference");
connect(action, &QAction::triggered, qApp, [] {
- QDesktopServices::openUrl(QUrl("https://apidocs.projectathena.dev/"));
+ QDesktopServices::openUrl(QUrl("https://apidocs.vircadia.dev/"));
});
addActionToQMenuAndActionHash(helpMenu, "Controls Reference", 0, qApp, SLOT(showHelp()));
@@ -815,7 +815,7 @@ Menu::Menu() {
// Help > Release Notes
action = addActionToQMenuAndActionHash(helpMenu, "Release Notes");
connect(action, &QAction::triggered, qApp, [] {
- QDesktopServices::openUrl(QUrl("https://docs.projectathena.dev/release-notes.html"));
+ QDesktopServices::openUrl(QUrl("https://docs.vircadia.dev/release-notes.html"));
});
// Help > Report a Bug!
@@ -782,21 +782,21 @@ Menu::Menu() {
});
helpMenu->addSeparator();
- // Help > Athena Docs
+ // Help > Vircadia Docs
action = addActionToQMenuAndActionHash(helpMenu, "Online Documentation");
connect(action, &QAction::triggered, qApp, [] {
@@ -782,21 +782,21 @@ Menu::Menu() {
});
- // Help > Athena Forum
+ // Help > Vircadia Forum
/* action = addActionToQMenuAndActionHash(helpMenu, "Online Forums");
connect(action, &QAction::triggered, qApp, [] {